IRouteState class

单一的路由状态 push,pop,setNewPath三处要通知

Inheritance

Constructors

IRouteState()
factory

Properties

canPop bool
no setter
currentConfiguration String?
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
home RouteBuilder?
getter/setter pair
routes → dynamic
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stack List<Page>
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pop() → void
push(String path) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setNewRoutePath(String path) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

inited bool
getter/setter pair

Static Methods

init(Map<String, RouteBuilder> routes) → dynamic
初始化,用于指定routes,routes是必须有得